=== added directory 'tools/groovy'
=== added file 'tools/groovy/app-install.sh'
--- tools/groovy/app-install.sh	1970-01-01 00:00:00 +0000
+++ tools/groovy/app-install.sh	2020-05-21 09:10:21 +0000
@@ -0,0 +1,71 @@
+#! /bin/sh
+
+set -e
+
+N="$1"
+# The location of the tree where we should install app-install data files
+DIR="$2"
+
+if [ "$PROJECT" = edubuntu ]; then
+    EDU_APP_INSTALL_DATA_DEB="$($BASEDIR/tools/apt-selection cache \
+				show app-install-data-edubuntu | \
+				grep ^Filename: | awk '{print $2}' || true)"
+
+    [ "$EDU_APP_INSTALL_DATA_DEB" ] || exit 0
+
+    mkdir -p "$DIR/app-install/edubuntu/"
+    TMP_EDU="$DIR/app-install/edubuntu/"
+
+    dpkg -x "$MIRROR/$EDU_APP_INSTALL_DATA_DEB" "$TMP_EDU"
+fi
+
+APP_INSTALL_DATA_DEB="$($BASEDIR/tools/apt-selection cache \
+			show app-install-data | \
+			grep ^Filename: | awk '{print $2}' || true)"
+[ "$APP_INSTALL_DATA_DEB" ] || exit 0
+
+mkdir -p "$DIR/app-install/channels" "$DIR/app-install/desktop" \
+	 "$DIR/app-install/icons" "$DIR/app-install/tmp"
+TMP="$DIR/app-install/tmp"
+dpkg -x "$MIRROR/$APP_INSTALL_DATA_DEB" "$TMP"
+
+find "$TMP/usr/share/app-install/desktop" \
+    -name \*.desktop -print0 | \
+    xargs -r0 grep -aHi '^X-AppInstall-Package=' | \
+    perl -pe "s,^$TMP/usr/share/app-install/desktop/,,; s/\.desktop:.*?=/ /" | \
+    sort -k2 > "$TMP/desktop-list"
+DESKTOPS="$(sort "$DIR/../$N.packages" | \
+	    join -1 2 -o 1.1 "$TMP/desktop-list" -)"
+
+for name in $DESKTOPS; do
+    desktop="$TMP/usr/share/app-install/desktop/$name.desktop"
+    cp -a "$desktop" "$DIR/app-install/desktop/"
+    icon="$(grep -ai '^Icon=' "$desktop" | head -n1 | cut -d= -f2)"
+    if [ "$icon" ]; then
+	if [ "${icon%.*}" = "$icon" ]; then
+	    cp -a "$TMP/usr/share/app-install/icons/$icon".* \
+		"$DIR/app-install/icons/" || true
+	else
+	    cp -a "$TMP/usr/share/app-install/icons/$icon" \
+		"$DIR/app-install/icons/" || true
+	fi
+    fi
+done
+
+if [ "$PROJECT" = edubuntu ]; then
+    find "$TMP_EDU/usr/share/app-install-data-edubuntu/desktop/" -type f -print0 | \
+	xargs -0r cp --target-directory "$DIR/app-install/desktop" || true
+    find "$TMP_EDU/usr/share/app-install-data-edubuntu/icons/" -type f -print0 | \
+	xargs -0r cp --target-directory "$DIR/app-install/icons" || true
+    rm -rf "$DIR/app-install/edubuntu"
+else
+    cp -a "$TMP/usr/share/app-install/desktop/applications.menu" \
+	"$DIR/app-install/desktop/" || true
+fi
+
+rm -rf "$DIR/app-install/tmp"
+
+mkdir -p "$DIR/.disk"
+echo '/app-install' > "$DIR/.disk/add-on"
+
+exit 0

=== added file 'tools/groovy/installtools.sh'
--- tools/groovy/installtools.sh	1970-01-01 00:00:00 +0000
+++ tools/groovy/installtools.sh	2020-05-21 09:10:21 +0000
@@ -0,0 +1,103 @@
+#!/bin/bash
+
+# Install files in /install and some in /doc
+set -e
+
+# The location of the tree for CD#1, passed in
+DIR=$1
+
+if [ "$CDIMAGE_INSTALL_BASE" = 1 ]; then
+    DOCDIR=doc
+
+    if [ -n "$BOOTDISKS" -a -e $BOOTDISKS/current/$DOCDIR ] ; then
+            DOCS=$BOOTDISKS/current/$DOCDIR
+    elif MANUALDEB="$($BASEDIR/tools/apt-selection cache show "installation-guide-$ARCH")"; then
+            MANUALDEB="$(echo "$MANUALDEB" | grep ^Filename | awk '{print $2}')"
+    else
+            echo "WARNING: Using $DI_CODENAME bootdisk documentation"
+            DOCS=$MIRROR/dists/$DI_CODENAME/main/installer-$ARCH/current/$DOCDIR
+    fi
+
+    # Put the install documentation in /doc/install
+    if [ "$DOCS" ] && [ -d "$DOCS" ]; then
+        cd $DOCS
+        mkdir -p $DIR/$DOCDIR/install
+        if ! cp -a * $DIR/$DOCDIR/install; then
+            echo "ERROR: Unable to copy installer documentation to CD."
+        fi
+    elif [ "$MANUALDEB" ]; then
+        mkdir -p "$DIR/$DOCDIR/install/tmp" "$DIR/$DOCDIR/install/manual"
+        dpkg -x "$MIRROR/$MANUALDEB" "$DIR/$DOCDIR/install/tmp"
+        mv "$DIR/$DOCDIR/install/tmp/usr/share/doc/installation-guide-$ARCH"/* "$DIR/$DOCDIR/install/manual/"
+        rm -rf "$DIR/$DOCDIR/install/tmp"
+        # just keep the HTML version
+        rm -f "$DIR/$DOCDIR/install/manual/copyright" \
+            "$DIR/$DOCDIR/install/manual/changelog.gz" \
+            "$DIR/$DOCDIR/install/manual"/*/install.*.pdf* \
+            "$DIR/$DOCDIR/install/manual"/*/install.*.txt*
+    else
+        echo "ERROR: Unable to copy installer documentation to CD."
+    fi
+fi
+
+# Preseed files for special install types
+mkdir -p $DIR/preseed
+PRESEED_ROOT=$BASEDIR/data/$CODENAME/preseed
+for preseed_dir in \
+        $PRESEED_ROOT $PRESEED_ROOT/$ARCH \
+        $PRESEED_ROOT/$PROJECT $PRESEED_ROOT/$PROJECT/$ARCH; do
+    [ -d "$preseed_dir" ] || continue
+    for file in $preseed_dir/*.seed; do
+        cp -a "$file" $DIR/preseed/
+    done
+done
+if [ "$CDIMAGE_DVD" = 1 ] && [ "$PROJECT" != ubuntu-server ]; then
+    # include server on normal DVDs
+    for preseed_dir in \
+            $PRESEED_ROOT/ubuntu-server $PRESEED_ROOT/ubuntu-server/$ARCH; do
+        [ -d "$preseed_dir" ] || continue
+        for file in $preseed_dir/*.seed; do
+            cp -a "$file" $DIR/preseed/
+        done
+    done
+    # we normally preseed tasksel to install the desktop task, but this is
+    # inappropriate on DVDs where much more choice is available
+    if [ -e "$DIR/preseed/$PROJECT.seed" ]; then
+        perl -ni -e '
+            if (/^#/) { $out .= $_ }
+            elsif (m[^tasksel\s+tasksel/first\s]) { print $out; print; print "tasksel\ttasksel/first\tseen false\n"; $out = "" }
+            else { print $out; print; $out = "" }' \
+                "$DIR/preseed/$PROJECT.seed"
+        if [ ! -s "$DIR/preseed/$PROJECT.seed" ]; then
+            rm -f "$DIR/preseed/$PROJECT.seed"
+        fi
+    fi
+fi
+# On live CDs, remove preseed/early_command settings that use the debconf
+# confmodule. Live CDs implement preseed/early_command in casper which
+# doesn't have the confmodule available.
+if [ "$CDIMAGE_LIVE" = 1 ]; then
+    for file in $DIR/preseed/*.seed; do
+        [ -f "$file" ] || continue
+        sed -i '/preseed\/early_command.*confmodule/d' "$file"
+    done
+fi
+
+if [ "$BACKPORT_KERNEL" ]; then
+    (cd $DIR/preseed/ &&
+    case $ARCH in
+        amd64|i386|arm64|ppc64el|s390x)
+            for file in *.seed; do
+                [ -f "$file" ] || continue
+                cp "$file" hwe-"$file"
+                if grep -q base-installer/kernel/override-image "$file"; then
+                    sed -i -e "s/string linux-virtual/string linux-virtual-$BACKPORT_KERNEL/" hwe-"$file"
+                elif ! grep -q base-installer/kernel/altmeta "$file"; then
+                    echo "d-i  base-installer/kernel/altmeta   string $BACKPORT_KERNEL" >> hwe-"$file"
+                fi
+                [ "$PROJECT" = "ubuntu-server" ] || mv hwe-"$file" "$file"
+            done
+            ;;
+    esac
+    )
+fi

=== added file 'tools/groovy/upgrade.sh'
--- tools/groovy/upgrade.sh	1970-01-01 00:00:00 +0000
+++ tools/groovy/upgrade.sh	2020-05-21 09:10:21 +0000
@@ -0,0 +1,41 @@
+#!/bin/sh
+set -e
+
+# Include dist-upgrader dir when available
+
+DIR="$1/CD1"
+TARGETDIR="$DIR/dists/$CODENAME/main/dist-upgrader/binary-all"
+
+# Assume that -security is always pocket copied to -updates
+UPGRADER_POCKETS="$CODENAME-updates $CODENAME"
+if [ "${PROPOSED:-0}" != "0" ]; then
+    UPGRADER_POCKETS="$CODENAME-proposed $UPGRADER_POCKETS"
+fi
+
+SOURCEDIR=""
+for POCKET in $UPGRADER_POCKETS; do
+    if [ -e "$MIRROR/dists/$POCKET/main/dist-upgrader-all/current/$CODENAME.tar.gz" ]; then
+        SOURCEDIR="$MIRROR/dists/$POCKET/main/dist-upgrader-all/current"
+        break
+    fi
+done
+
+if [ -n "$SOURCEDIR" ]; then
+    mkdir -p "$TARGETDIR"
+    # copy upgrade tarball + signature
+    cp -av "$SOURCEDIR/$CODENAME"* "$TARGETDIR"
+    # extract the cdromupgrade script from the archive and put it
+    # onto the top-level of the CD
+    tar -C "$DIR" -x -z -f "$TARGETDIR/$CODENAME.tar.gz" ./cdromupgrade
+fi
+
+# now check if any prerequisites need to go onto the CD
+PACKAGESGZ="$MIRROR/dists/$PREV_CODENAME-updates/main/binary-$ARCH/Packages.gz"
+ARCH_TARGETDIR="$DIR/dists/$CODENAME/main/dist-upgrader/binary-$ARCH"
+mkdir -p "$ARCH_TARGETDIR"
+for pkg in $(zcat "$PACKAGESGZ" | grep-dctrl -PensFilename '^(release-upgrader-python-apt|libapt-inst1|libapt-pkg4)'); do
+    echo "Adding: $pkg"
+    cp -a "$MIRROR/$pkg" "$ARCH_TARGETDIR"
+done
+
+exit 0

